==> haskell-reducers-3.12.5-119.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-AExear36UrA4z6wgWtct1l
key:                  reducers-3.12.5-AExear36UrA4z6wgWtct1l
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  3bc13842c94255fc0053684a02360456
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-AExear36UrA4z6wgWtct1l
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.6.2-1PgNfRTFIgw8zTTFVYZdaB
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.5-120-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-8ZhPkObIjbz4xpF2CpKfJ
key:                  reducers-3.12.5-8ZhPkObIjbz4xpF2CpKfJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  02b4636cba635cf8a7a838ac840b47f9
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-8ZhPkObIjbz4xpF2CpKfJ
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.6.2-9C2f3k75hFcCEg0BQd5B9P
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
